==> App-MFILE-WWW-0.159.tar.gz: App-MFILE-WWW-0.159/share/js/core/login.js <==
// *************************************************************************
// Copyright (c) 2014-2017, SUSE LLC
//
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// 3. Neither the name of SUSE LLC nor the names of its contributors may be
// used to endorse or promote products derived from this software without
// specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
// *************************************************************************
//
// login.js
//
// Just log in
//
"use strict";

define ([
    'jquery',
    'ajax',
    'cf',
    'current-user',
    'html',
    'lib'
], function (
    $,
    ajax,
    cf,
    currentUser,
    html,
    lib
) {

    return function (nam, pwd) {

        var found,
            i,
            rest = {
                "method": 'LOGIN',
                "path": 'login',
                "body": { "nam": nam,
                          "pwd": pwd }
            },
            // success callback
            sc = function (st) {
                // trigger GET request to the server -- no console.log messages here
                // because the reload will make them go away
                if (cf('testing')) {
                    console.log("Login successful!");
                    currentUser('obj', st.payload.emp);
                    currentUser('priv', st.payload.priv);
                } else {
                    location.reload();
                }
            },
            // failure callback
            fc = function (st) {
                console.log("Login failed", st);
                $('#result').html('Login failed: code ' + st.payload.code + ' (' + st.payload.message + ')');
                $('input[name="nam"]').focus();
                $('input[name="pwd"]').val('');
            };

        ajax(rest, sc, fc);

    };

});

==> App-MFILE-WWW-0.160.tar.gz: App-MFILE-WWW-0.160/share/js/core/login.js <==
// *************************************************************************
// Copyright (c) 2014-2017, SUSE LLC
//
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// 3. Neither the name of SUSE LLC nor the names of its contributors may be
// used to endorse or promote products derived from this software without
// specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
// *************************************************************************
//
// login.js
//
// Just log in
//
"use strict";

define ([
    'jquery',
    'ajax',
    'cf',
    'current-user',
    'html',
    'lib'
], function (
    $,
    ajax,
    cf,
    currentUser,
    html,
    lib
) {

    return function (body) {

        var found,
            i,
            rest = {
                "method": 'LOGIN',
                "path": 'login',
                "body": body
            },
            // success callback
            sc = function (st) {
                // trigger GET request to the server -- no console.log messages here
                // because the reload will make them go away
                if (cf('testing')) {
                    console.log("Login successful!");
                    currentUser('obj', st.payload.emp);
                    currentUser('priv', st.payload.priv);
                } else {
                    location.reload();
                }
            },
            // failure callback
            fc = function (st) {
                console.log("Login failed", st);
                $('#result').html('Login failed: code ' + st.payload.code + ' (' + st.payload.message + ')');
                $('input[name="nam"]').focus();
                $('input[name="pwd"]').val('');
            };

        ajax(rest, sc, fc);

    };

});
